@@ -1,10 +1,13 @@
-import oaas
+from typing import Any, Optional, Dict
+
 from oaas_grpc.server import OaasGrpcServer
 from oaas_grpc.server.find_ips import find_ips
 from oaas_registry_api import OaasRegistryStub
 from oaas_registry_api.rpc.registry_pb2 import OaasServiceDefinition
 from oaas_simple.server.service_invoker_proxy import noop
 
+import oaas
+
 noop()
 
 
@@ -51,3 +54,24 @@ class OaasSimpleServer(oaas.ServerMiddleware):
     def can_serve(self, service_definition: oaas.ServiceDefinition) -> bool:
         # We can serve both gRPC, and simple services, since we embed both
         return True
+
+    def can_publish(self, *, instance: Any) -> bool:
+        return False
+
+    def publish(
+        self,
+        instance: Any,
+        name: str,
+        namespace: str = "default",
+        version: str = "1",
+        tags: Optional[Dict[str, str]] = None,
+    ) -> str:
+        raise Exception(
+            f"Simple service middleware can't dynamically publish services. "
+            f"Can't serve service {instance}"
+        )
+
+    def unpublish(self, id: str) -> None:
+        raise Exception(
+            "Simple service middleware can't dynamically unpublish services"
+        )
